"""When the package is executed, this is the entry point

Importing the main.py will start interactive demo of the package.
"""


from play import run
run()
